@@ -277,6 +277,7 @@ pub static ATOMS: &'static [&'static str] = &[
     "border-top-width",
     "border-width",
     "bottom",
+    "box-shadow",
     "butt",
     "bvar",
     "by",
@@ -501,6 +502,8 @@ pub static ATOMS: &'static [&'static str] = &[
     "filterRes",
     "filterunits",
     "filterUnits",
+    "flex-grow",
+    "flex-shrink",
     "float",
     "flood",
     "flood-color",
@@ -920,6 +923,7 @@ pub static ATOMS: &'static [&'static str] = &[
     "outerproduct",
     "outline",
     "outline-color",
+    "outline-offset",
     "outline-style",
     "outline-width",
     "output",
@@ -948,6 +952,7 @@ pub static ATOMS: &'static [&'static str] = &[
     "patternTransform",
     "patternunits",
     "patternUnits",
+    "perspective",
     "pi",
     "piece",
     "piecewise",
@@ -1157,16 +1162,18 @@ pub static ATOMS: &'static [&'static str] = &[
     "tel",
     "tendsto",
     "text",
-    "text/plain",
     "text-align",
     "text-anchor",
     "text-decoration",
+    "text-indent",
+    "text-orientation",
+    "text-rendering",
+    "text-shadow",
+    "text/plain",
     "textlength",
     "textLength",
-    "text-orientation",
     "textpath",
     "textPath",
-    "text-rendering",
     "thickmathspace",
     "thinmathspace",
     "time",
@@ -1175,6 +1182,7 @@ pub static ATOMS: &'static [&'static str] = &[
     "top",
     "touchevent",
     "transform",
+    "transform-origin",
     "transition-delay",
     "transition-duration",
     "transition-property",
@@ -1277,6 +1285,7 @@ pub static ATOMS: &'static [&'static str] = &[
     "ychannelselector",
     "yChannelSelector",
     "z",
+    "z-index",
     "zoomandpan",
     "zoomAndPan",
 ];
